@@ -14,7 +14,7 @@ at the top-level directory.
  * \brief Driver program for pdgssvx_ABglobal example
  *
  * <pre>
- * -- Distributed SuperLU routine (version 4.1) --
+ * -- Distributed SuperLU routine (version 9.0) --
  * Lawrence Berkeley National Lab, Univ. of California Berkeley.
  * September 1, 1999
  * April 5, 2015
@@ -61,7 +61,7 @@ int main(int argc, char *argv[])
     int      iam, info, ldb, ldx, nrhs;
     char     trans[1];
     char     **cpp, c;
-    FILE *fp, *fopen();
+    FILE *fp;
     extern int cpp_defs();
 
     nprow = 1;  /* Default process rows.      */
