@@ -1,9 +1,9 @@
 /*! \file
 Copyright (c) 2003, The Regents of the University of California, through
-Lawrence Berkeley National Laboratory (subject to receipt of any required 
-approvals from U.S. Dept. of Energy) 
+Lawrence Berkeley National Laboratory (subject to receipt of any required
+approvals from U.S. Dept. of Energy)
 
-All rights reserved. 
+All rights reserved.
 
 The source code is distributed under BSD license, see the file License.txt
 at the top-level directory.
@@ -14,13 +14,13 @@ at the top-level directory.
  * \brief Driver program for PDGSSVX3D example
  *
  * <pre>
- * -- Distributed SuperLU routine (version 7.0) --
+ * -- Distributed SuperLU routine (version 9.0) --
  * Lawrence Berkeley National Lab, Georgia Institute of Technology,
- * Oak Ridge National Lab 
+ * Oak Ridge National Lab
  * September 10, 2021
  *
  */
-#include "superlu_ddefs.h"  
+#include "superlu_ddefs.h"
 
 /*! \brief
  *
@@ -30,7 +30,7 @@ at the top-level directory.
  *
  * The driver program PDDRIVE3D3.
  *
- * This example illustrates how to use PDGSSVX3D to sovle 
+ * This example illustrates how to use PDGSSVX3D to sovle
  * the systems with the same sparsity pattern and similar numerical
  * values of matrix A.
  * In this case, the row and column permutation vectors and symbolic
@@ -54,7 +54,7 @@ at the top-level directory.
  *
  * </pre>
  */
- 
+
 static void matCheck(int n, int m, double* A, int LDA,
        double* B, int LDB)
 {
@@ -111,7 +111,7 @@ main (int argc, char *argv[])
 {
     superlu_dist_options_t options;
     SuperLUStat_t stat;
-    SuperMatrix A;  // Now, A is on all 3D processes  
+    SuperMatrix A;  // Now, A is on all 3D processes
     dScalePermstruct_t ScalePermstruct;
     dLUstruct_t LUstruct;
     dSOLVEstruct_t SOLVEstruct;
@@ -120,15 +120,20 @@ main (int argc, char *argv[])
     double *b, *b1, *xtrue, *xtrue1;
     int m, n, i, j, m_loc;
     int nprow, npcol, npdep;
+    int lookahead, colperm, rowperm, ir;
     int iam, info, ldb, ldx, nrhs, ii, omp_mpi_level;
     char **cpp, c, *suffix;
-    FILE *fp, *fopen ();
+    FILE *fp;
     extern int cpp_defs ();
-    
+
     nprow = 1;            /* Default process rows.      */
     npcol = 1;            /* Default process columns.   */
     npdep = 1;            /* replication factor must be power of two */
     nrhs = 1;             /* Number of right-hand side. */
+    lookahead = -1;
+    colperm = -1;
+    rowperm = -1;
+    ir = -1;
 
     /* ------------------------------------------------------------
        INITIALIZE MPI ENVIRONMENT.
@@ -172,6 +177,14 @@ main (int argc, char *argv[])
             case 'd':
                 npdep = atoi (*cpp);
                 break;
+            case 'l': lookahead = atoi(*cpp);
+                      break;
+            case 'p': rowperm = atoi(*cpp);
+                      break;
+            case 'q': colperm = atoi(*cpp);
+                      break;
+            case 'i': ir = atoi(*cpp);
+                      break;
             }
         }
         else
@@ -209,8 +222,9 @@ main (int argc, char *argv[])
 	    fflush(stdout);
 	    break;
 	}
+        fflush(stdout);
     }
-	
+
     /* Bail out if I do not belong in the grid. */
     iam = grid.iam;
     if (iam == -1)     goto out;
@@ -248,9 +262,9 @@ main (int argc, char *argv[])
     dcreate_matrix_postfix3d(&A, nrhs, &b, &ldb,
                              &xtrue, &ldx, fp, suffix, &(grid));
     fclose(fp);
-    
+
     //printf("ldx %d, ldb %d\n", ldx, ldb);
-    
+
     if (!(berr = doubleMalloc_dist (nrhs)))
         ABORT ("Malloc fails for berr[].");
 
@@ -264,7 +278,7 @@ main (int argc, char *argv[])
        options.ColPerm           = METIS_AT_PLUS_A;
        options.RowPerm           = LargeDiag_MC64;
        options.ReplaceTinyPivot  = NO;
-       options.IterRefine        = DOUBLE;
+       options.IterRefine        = SLU_DOUBLE;
        options.Trans             = NOTRANS;
        options.SolveInitialized  = NO;
        options.RefineInitialized = NO;
@@ -283,13 +297,17 @@ main (int argc, char *argv[])
     options.ReplaceTinyPivot = YES;
 #endif
 
+    if (rowperm != -1) options.RowPerm = rowperm;
+    if (colperm != -1) options.ColPerm = colperm;
+    if (lookahead != -1) options.num_lookaheads = lookahead;
+    if (ir != -1) options.IterRefine = ir;
+
     if (!iam) {
-	print_sp_ienv_dist(&options);
 	print_options_dist(&options);
 	fflush(stdout);
     }
 
-    // matrix is on 3D process grid  
+    // matrix is on 3D process grid
     m = A.nrow;
     n = A.ncol;
 
@@ -315,19 +333,16 @@ main (int argc, char *argv[])
         pdinf_norm_error (iam, ((NRformat_loc *) A.Store)->m_loc,
                               nrhs, b, ldb, xtrue, ldx, grid.comm);
     }
-    
+
     /* Deallocate some storage, including replicated LU structure along
        the Z dimension. keep around 2D matrix meta structure, including
        the LU data structure on the host side.  */
     Destroy_CompRowLoc_Matrix_dist (&A);
-    
+
     if ( (grid.zscp).Iam == 0 ) { // process layer 0
 	PStatPrint (&options, &stat, &(grid.grid2d)); /* Print 2D statistics.*/
-    } else { // Process layers not equal 0
-        dDeAllocLlu_3d(n, &LUstruct, &grid);
-        dDeAllocGlu_3d(&LUstruct);
     }
-    
+
     PStatFree(&stat);
     SUPERLU_FREE(b);     /* Free storage of right-hand side.*/
     SUPERLU_FREE(xtrue); /* Free storage of the exact solution.*/
@@ -337,7 +352,7 @@ main (int argc, char *argv[])
           ONLY THE SPARSITY PATTERN OF MATRIX A IS THE SAME.
        ------------------------------------------------------------*/
     options.Fact = SamePattern_SameRowPerm;
-    
+
     /* Zero the numerical values in L and U.  */
     if ( (grid.zscp).Iam == 0 ) { /* on 2D grid-0 */
         dZeroLblocks(iam, n, &(grid.grid2d), &LUstruct);
@@ -368,7 +383,7 @@ main (int argc, char *argv[])
         pdinf_norm_error (iam, ((NRformat_loc *) A.Store)->m_loc,
                               nrhs, b1, ldb, xtrue1, ldx, grid.comm);
     }
-    
+
     /* ------------------------------------------------------------
        DEALLOCATE ALL STORAGE.
        ------------------------------------------------------------ */
@@ -376,14 +391,11 @@ main (int argc, char *argv[])
     if ( grid.zscp.Iam == 0 ) { // process layer 0
 
 	PStatPrint (&options, &stat, &(grid.grid2d)); /* Print 2D statistics.*/
-
-        dDestroy_LU (n, &(grid.grid2d), &LUstruct);
-        dSolveFinalize (&options, &SOLVEstruct);
-    } else { // Process layers not equal 0
-        dDeAllocLlu_3d(n, &LUstruct, &grid);
-        dDeAllocGlu_3d(&LUstruct);
     }
-    
+    dSolveFinalize (&options, &SOLVEstruct);
+    dDestroy_LU (n, &(grid.grid2d), &LUstruct);
+
+
     dDestroy_A3d_gathered_on_2d(&SOLVEstruct, &grid);
 
     dScalePermstructFree (&ScalePermstruct);
