@@ -14,7 +14,7 @@ at the top-level directory.
  * \brief Driver program for pdgssvx_ABglobal example
  *
  * <pre>
- * -- Distributed SuperLU routine (version 1.0) --
+ * -- Distributed SuperLU routine (version 9.0) --
  * Lawrence Berkeley National Lab, Univ. of California Berkeley.
  * September 1, 1999
  * </pre>
@@ -62,7 +62,7 @@ int main(int argc, char *argv[])
     int      iam, info, ldb, ldx, nrhs;
     char     trans[1];
     char     **cpp, c;
-    FILE *fp, *fopen();
+    FILE *fp;
     extern int cpp_defs();
 
     nprow = 1;  /* Default process rows.      */
@@ -162,8 +162,17 @@ int main(int argc, char *argv[])
     *trans = 'N';
     ldx = n;
     ldb = m;
-    dGenXtrue_dist(n, nrhs, xtrue, ldx);
-    dFillRHS_dist(trans, nrhs, xtrue, ldx, &A, b, ldb);
+
+    if ( iam==0 ) {
+        dGenXtrue_dist(n, nrhs, xtrue, ldx);
+        dFillRHS_dist(trans, nrhs, xtrue, ldx, &A, b, ldb);
+	
+        MPI_Bcast( xtrue, n*nrhs, MPI_DOUBLE, 0, grid.comm );
+        MPI_Bcast( b, m*nrhs, MPI_DOUBLE, 0, grid.comm );
+    } else {
+        MPI_Bcast( xtrue, n*nrhs, MPI_DOUBLE, 0, grid.comm );
+        MPI_Bcast( b, m*nrhs, MPI_DOUBLE, 0, grid.comm );
+    }
 
     if ( !(berr = doubleMalloc_dist(nrhs)) )
 	ABORT("Malloc fails for berr[].");
