@@ -201,7 +201,7 @@ int main(int argc, char *argv[])
     if (ir != -1) options.IterRefine = ir;
     if (symbfact != -1) options.ParSymbFact = symbfact;
 
-    int superlu_acc_offload = sp_ienv_dist(10, &options); //get_acc_offload();
+    int superlu_acc_offload = get_acc_offload(&options);
     
     /* In the batch mode: create multiple SuperLU grids,
         each grid solving one linear system. */
