@@ -1,20 +1,20 @@
 /*! \file
 Copyright (c) 2003, The Regents of the University of California, through
-Lawrence Berkeley National Laboratory (subject to receipt of any required 
-approvals from U.S. Dept. of Energy) 
+Lawrence Berkeley National Laboratory (subject to receipt of any required
+approvals from U.S. Dept. of Energy)
 
-All rights reserved. 
+All rights reserved.
 
 The source code is distributed under BSD license, see the file License.txt
 at the top-level directory.
 */
 
 
-/*! @file 
+/*! @file
  * \brief This example illustrates how to divide up the processes into subgroups
  *
  * <pre>
- * -- Distributed SuperLU routine (version 6.1) --
+ * -- Distributed SuperLU routine (version 9.0) --
  * Lawrence Berkeley National Lab, Univ. of California Berkeley.
  * March 15, 2003
  * April 5, 2015
@@ -66,14 +66,14 @@ int main(int argc, char *argv[])
     int      nrhs = 1;   /* Number of right-hand side. */
     int ii, omp_mpi_level;
     char     **cpp, c, *postfix;
-    FILE *fp, *fopen();
+    FILE *fp;
     int cpp_defs();
 
 
     /* ------------------------------------------------------------
-       INITIALIZE MPI ENVIRONMENT. 
+       INITIALIZE MPI ENVIRONMENT.
        ------------------------------------------------------------*/
-    MPI_Init_thread( &argc, &argv, MPI_THREAD_MULTIPLE, &omp_mpi_level); 
+    MPI_Init_thread( &argc, &argv, MPI_THREAD_MULTIPLE, &omp_mpi_level);
 
     MPI_Comm_size( MPI_COMM_WORLD, &nprocs );
     if ( nprocs < 10 ) {
@@ -107,7 +107,7 @@ int main(int argc, char *argv[])
     }
 
     /* ------------------------------------------------------------
-       INITIALIZE THE SUPERLU PROCESS GRID 1. 
+       INITIALIZE THE SUPERLU PROCESS GRID 1.
        ------------------------------------------------------------*/
     nprow = 2;
     npcol = 3;
@@ -118,7 +118,7 @@ int main(int argc, char *argv[])
     superlu_gridmap(MPI_COMM_WORLD, nprow, npcol, usermap, ldumap, &grid1);
 
     /* ------------------------------------------------------------
-       INITIALIZE THE SUPERLU PROCESS GRID 2. 
+       INITIALIZE THE SUPERLU PROCESS GRID 2.
        ------------------------------------------------------------*/
     nprow = 2;
     npcol = 2;
@@ -131,7 +131,7 @@ int main(int argc, char *argv[])
     /* Bail out if I do not belong in any of the 2 grids. */
     MPI_Comm_rank( MPI_COMM_WORLD, &iam );
     if ( iam == -1 ) goto out;
-    
+
 #if ( DEBUGlevel>=1 )
     CHECK_MALLOC(iam, "Enter main()");
 #endif
@@ -147,17 +147,17 @@ int main(int argc, char *argv[])
 	iam = grid1.iam;  /* Get the logical number in the new grid. */
 
         /* ------------------------------------------------------------
-           GET THE MATRIX FROM FILE AND SETUP THE RIGHT HAND SIDE. 
+           GET THE MATRIX FROM FILE AND SETUP THE RIGHT HAND SIDE.
            ------------------------------------------------------------*/
         screate_matrix_postfix(&A, nrhs, &b, &ldb, &xtrue, &ldx, fp, postfix, &grid1);
-	
+
 	if ( !(berr = floatMalloc_dist(nrhs)) )
 	    ABORT("Malloc fails for berr[].");
 
 	/* ------------------------------------------------------------
 	   NOW WE SOLVE THE LINEAR SYSTEM.
 	   ------------------------------------------------------------*/
-	
+
         /* Set the default input options:
             options.Fact = DOFACT;
             options.Equil = YES;
@@ -173,7 +173,6 @@ int main(int argc, char *argv[])
 	set_default_options_dist(&options);
 
         if (!iam) {
-	    print_sp_ienv_dist(&options);
     	    print_options_dist(&options);
         }
 
@@ -186,7 +185,7 @@ int main(int argc, char *argv[])
 
 	/* Initialize the statistics variables. */
 	PStatInit(&stat);
-	
+
 	/* Call the linear equation solver. */
 	psgssvx(&options, &A, &ScalePermstruct, b, ldb, nrhs, &grid1,
                 &LUstruct, &SOLVEstruct, berr, &stat, &info);
@@ -201,7 +200,7 @@ int main(int argc, char *argv[])
             psinf_norm_error(iam, ((NRformat_loc *)A.Store)->m_loc,
                              nrhs, b, ldb, xtrue, ldx, grid1.comm);
 	}
-    
+
 	/* Print the statistics. */
 	PStatPrint(&options, &stat, &grid1);
 
@@ -224,7 +223,7 @@ int main(int argc, char *argv[])
 	iam = grid2.iam;  /* Get the logical number in the new grid. */
 
         /* ------------------------------------------------------------
-           GET THE MATRIX FROM FILE AND SETUP THE RIGHT HAND SIDE. 
+           GET THE MATRIX FROM FILE AND SETUP THE RIGHT HAND SIDE.
            ------------------------------------------------------------*/
         screate_matrix_postfix(&A, nrhs, &b, &ldb, &xtrue, &ldx, fp, postfix, &grid2);
 
@@ -234,7 +233,7 @@ int main(int argc, char *argv[])
 	/* ------------------------------------------------------------
 	   NOW WE SOLVE THE LINEAR SYSTEM.
 	   ------------------------------------------------------------*/
-	
+
         /* Set the default input options:
             options.Fact = DOFACT;
             options.Equil = YES;
@@ -248,7 +247,7 @@ int main(int argc, char *argv[])
             options.PrintStat = YES;
          */
 	set_default_options_dist(&options);
-	
+
         m = A.nrow;
         n = A.ncol;
 
@@ -258,7 +257,7 @@ int main(int argc, char *argv[])
 
 	/* Initialize the statistics variables. */
 	PStatInit(&stat);
-	
+
 	/* Call the linear equation solver. */
 	psgssvx(&options, &A, &ScalePermstruct, b, ldb, nrhs, &grid2,
                 &LUstruct, &SOLVEstruct, berr, &stat, &info);
@@ -273,7 +272,7 @@ int main(int argc, char *argv[])
             psinf_norm_error(iam, ((NRformat_loc *)A.Store)->m_loc,
                              nrhs, b, ldb, xtrue, ldx, grid2.comm);
         }
-	
+
 	/* Print the statistics. */
 	PStatPrint(&options, &stat, &grid2);
 
