@@ -1232,8 +1232,7 @@ void pdgssvx3d(superlu_dist_options_t *options, SuperMatrix *A,
 	  	   because perm_r[] and/or perm_c[] is changed.    */
 		if ( options->SolveInitialized == YES ) { /* Initialized before */
 			dSolveFinalize(options, SOLVEstruct); /* Clean up structure */
-			pdgstrs_delete_device_lsum_x(SOLVEstruct);
-			options->SolveInitialized = NO;   /* Reset the solve state */
+			if (get_acc_solve()) pdgstrs_delete_device_lsum_x(SOLVEstruct);
 		}
 	    }
 
@@ -1324,8 +1323,7 @@ void pdgssvx3d(superlu_dist_options_t *options, SuperMatrix *A,
 		       because perm_r[] and/or perm_c[] is changed.    */
 		    if ( options->SolveInitialized == YES ) { /* Initialized before */
 			dSolveFinalize(options, SOLVEstruct); /* Clean up structure */
-			pdgstrs_delete_device_lsum_x(SOLVEstruct);
-			options->SolveInitialized = NO;   /* Reset the solve state */
+			if (get_acc_solve()) pdgstrs_delete_device_lsum_x(SOLVEstruct);
 		    }
 		}
 
@@ -1605,7 +1603,7 @@ void pdgssvx3d(superlu_dist_options_t *options, SuperMatrix *A,
 		    /* Deallocate the storage associated with SOLVEstruct1 */
 		    if (nrhs > 1)
 		    {
-			pdgstrs_delete_device_lsum_x(SOLVEstruct1);
+			if (get_acc_solve()) pdgstrs_delete_device_lsum_x(SOLVEstruct1);
 			pxgstrs_finalize (SOLVEstruct1->gstrs_comm);
 			SUPERLU_FREE (SOLVEstruct1);
 		    }
@@ -1780,7 +1778,7 @@ void pdgssvx3d(superlu_dist_options_t *options, SuperMatrix *A,
 		    /* Deallocate the storage associated with SOLVEstruct1 */
 		    if (nrhs > 1)
 		    {
-			pdgstrs_delete_device_lsum_x(SOLVEstruct1);
+			if (get_acc_solve()) pdgstrs_delete_device_lsum_x(SOLVEstruct1);
 			pxgstrs_finalize (SOLVEstruct1->gstrs_comm);
 			SUPERLU_FREE (SOLVEstruct1);
 		    }
