@@ -55,7 +55,7 @@ LUstruct_v100::LUstruct_v100(int_t nsupers_, int_t ldt_,
 {
     maxLvl = log2i(grid3d->zscp.Np) + 1;
     isNodeInMyGrid = getIsNodeInMyGrid(nsupers, maxLvl, trf3Dpartition->myNodeCount, trf3Dpartition->treePerm);
-    superlu_acc_offload = sp_ienv_dist(10, options); //get_acc_offload();
+    superlu_acc_offload = get_acc_offload(options);
 
 #if (DEBUGlevel >= 1)
     CHECK_MALLOC(grid3d_in->iam, "Enter LUstruct_v100 constructor");
