@@ -1444,8 +1444,7 @@ void pdgssvx3d(superlu_dist_options_t *options, SuperMatrix *A,
 			because perm_r[] and/or perm_c[] is changed.    */
 			if ( options->SolveInitialized == YES ) { /* Initialized before */
 				dSolveFinalize(options, SOLVEstruct); /* Clean up structure */
-				pdgstrs_delete_device_lsum_x(SOLVEstruct);
-				options->SolveInitialized = NO;   /* Reset the solve state */
+				if (get_acc_solve()) pdgstrs_delete_device_lsum_x(SOLVEstruct);
 			}
 			}
 
@@ -1536,8 +1535,7 @@ if (get_acc_solve()){
 			because perm_r[] and/or perm_c[] is changed.    */
 			if ( options->SolveInitialized == YES ) { /* Initialized before */
 				dSolveFinalize(options, SOLVEstruct); /* Clean up structure */
-				pdgstrs_delete_device_lsum_x(SOLVEstruct);
-				options->SolveInitialized = NO;   /* Reset the solve state */
+				if (get_acc_solve()) pdgstrs_delete_device_lsum_x(SOLVEstruct);
 			}
 			}
 
@@ -1818,7 +1816,7 @@ if (get_acc_solve()){
 				/* Deallocate the storage associated with SOLVEstruct1 */
 				if (nrhs > 1)
 					{
-					pdgstrs_delete_device_lsum_x(SOLVEstruct1);
+					if (get_acc_solve()) pdgstrs_delete_device_lsum_x(SOLVEstruct1);
 					pxgstrs_finalize (SOLVEstruct1->gstrs_comm);
 					SUPERLU_FREE (SOLVEstruct1);
 					}
@@ -1992,7 +1990,7 @@ if (get_acc_solve()){
 				/* Deallocate the storage associated with SOLVEstruct1 */
 				if (nrhs > 1)
 					{
-					pdgstrs_delete_device_lsum_x(SOLVEstruct1);
+					if (get_acc_solve()) pdgstrs_delete_device_lsum_x(SOLVEstruct1);
 					pxgstrs_finalize (SOLVEstruct1->gstrs_comm);
 					SUPERLU_FREE (SOLVEstruct1);
 					}
